document.addEventListener('DOMContentLoaded', () => {
  const authButton = document.getElementById('authButton');
  const playlistForm = document.getElementById('playlistForm');
  const playlistContainer = document.getElementById('playlistContainer');
  
  let isAuthenticated = false;
  let playlists = [];

  // Simulated authentication
  authButton.addEventListener('click', () => {
    if (!isAuthenticated) {
      authButton.textContent = 'Sign Out';
      isAuthenticated = true;
      // Would implement actual Google OAuth here
    } else {
      authButton.textContent = 'Sign in with Google';
      isAuthenticated = false;
      clearPlaylists();
    }
  });

  playlistForm.addEventListener('submit', (e) => {
    e.preventDefault();
    if (!isAuthenticated) {
      alert('Please sign in first');
      return;
    }

    const title = document.getElementById('playlistTitle').value;
    const videoUrl = document.getElementById('videoUrl').value;
    
    if (videoUrl && !isValidYouTubeUrl(videoUrl)) {
      alert('Please enter a valid YouTube URL');
      return;
    }

    addPlaylist(title, videoUrl);
    playlistForm.reset();
  });

  function isValidYouTubeUrl(url) {
    const pattern = /^(https?:\/\/)?(www\.)?(youtube\.com|youtu\.?be)\/.+$/;
    return pattern.test(url);
  }

  function addPlaylist(title, videoUrl) {
    const playlist = {
      id: Date.now(),
      title,
      videos: videoUrl ? [{url: videoUrl, completed: false}] : [],
      expanded: false
    };

    playlists.push(playlist);
    renderPlaylists();
  }

  function renderPlaylists() {
    playlistContainer.innerHTML = '';
    playlists.forEach(playlist => {
      const playlistElement = createPlaylistElement(playlist);
      playlistContainer.appendChild(playlistElement);
    });
  }

  function createPlaylistElement(playlist) {
    const div = document.createElement('div');
    div.className = 'playlist-item';
    div.innerHTML = `
      <h3>${playlist.title}</h3>
      <button class="toggle-btn gothic-btn">
        ${playlist.expanded ? 'Collapse' : 'Expand'}
      </button>
    `;

    if (playlist.expanded) {
      const videoList = document.createElement('ul');
      playlist.videos.forEach(video => {
        const li = document.createElement('li');
        li.innerHTML = `
          <input type="checkbox" 
            ${video.completed ? 'checked' : ''}>
          <a href="${video.url}" target="_blank">
            ${video.url}
          </a>
        `;
        videoList.appendChild(li);
      });
      div.appendChild(videoList);
    }

    div.querySelector('.toggle-btn').addEventListener('click', () => {
      playlist.expanded = !playlist.expanded;
      renderPlaylists();
    });

    return div;
  }

  function clearPlaylists() {
    playlists = [];
    renderPlaylists();
  }
});